MtAudioErrorCode enum

Error codes for audio playback errors.

Inheritance
Available extensions

Values

sourceLoadFailed → const MtAudioErrorCode

Failed to load the audio source.

networkError → const MtAudioErrorCode

Network error while loading audio.

invalidFormat → const MtAudioErrorCode

Invalid audio format.

aborted → const MtAudioErrorCode

Playback was aborted.

decodingError → const MtAudioErrorCode

Audio decoding error.

unknown → const MtAudioErrorCode

Unknown error.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MtAudioErrorCode>
A constant List of the values in this enum, in order of their declaration.