MtCarPlayTab class

Configuration for a tab in CarPlay tab bar.

Constructors

MtCarPlayTab({required String title, required String systemIcon, required String rootId})
Creates an MtCarPlayTab.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
rootId String
Root ID to use when browsing this tab's content.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemIcon String
SF Symbol name for the tab icon.
final
title String
Tab display title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited