MtPlaybackStatus enum
Playback status of the audio player.
Values
- idle → const MtPlaybackStatus
-
Player is idle (no audio loaded).
- loading → const MtPlaybackStatus
-
Player is loading audio.
- buffering → const MtPlaybackStatus
-
Player is buffering.
- playing → const MtPlaybackStatus
-
Player is currently playing.
- paused → const MtPlaybackStatus
-
Player is paused.
- completed → const MtPlaybackStatus
-
Player has completed playback.
- error → const MtPlaybackStatus
-
Player encountered an error.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MtPlaybackStatus> - A constant List of the values in this enum, in order of their declaration.