MtPlayerState class
Player state exposed to builder function.
Constructors
- MtPlayerState({required MtPlaybackState playbackState, required MtPositionState positionState, required MtQueueState queueState, required MtAudioItem? currentItem, required double speed})
-
Creates an MtPlayerState.
const
Properties
- currentItem → MtAudioItem?
-
Currently playing item.
final
- duration → Duration?
-
Total duration.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool
-
Whether the player is loading.
no setter
- isPaused → bool
-
Whether the player is paused.
no setter
- isPlaying → bool
-
Whether the player is playing.
no setter
- playbackState → MtPlaybackState
-
Current playback state.
final
- position → Duration
-
Current position.
no setter
- positionState → MtPositionState
-
Current position state.
final
- progress → double
-
Playback progress (0.0 to 1.0).
no setter
- queueState → MtQueueState
-
Current queue state.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double
-
Current playback speed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited